@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2025  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2026  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -35,6 +35,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <osmium/memory/buffer.hpp>
 #include <osmium/osm/entity_bits.hpp>
 #include <osmium/osm/object.hpp>
+#include <osmium/osm/object_comparisons.hpp>
 #include <osmium/util/verbose_output.hpp>
 
 #include <boost/program_options.hpp>
@@ -146,10 +147,11 @@ namespace {
                 return true;
             }
 
-            if (m_iterator->id() < m_last_id) {
+            static constexpr osmium::id_order id_cmp{};
+            if (id_cmp(m_iterator->id(), m_last_id)) {
                 throw std::runtime_error{"Objects in input file '" + m_name + "' out of order (smaller ids must come first)."};
             }
-            if (m_iterator->id() > m_last_id) {
+            if (id_cmp(m_last_id, m_iterator->id())) {
                 m_last_id = m_iterator->id();
                 m_last_version = m_iterator->version();
                 return true;
