@@ -6,7 +6,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 http://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2025  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2026  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -64,7 +64,7 @@ public:
                    osmium::io::fsync fsync,
                    const options_type& options);
 
-    ~ExportFormatPg() override {
+    ~ExportFormatPg() noexcept override {
         try {
             close();
         } catch (...) {
