@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2025  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2026  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -84,7 +84,7 @@ void with_multiple_osm_inputs::setup_input_files(const boost::program_options::v
     }
 
     bool uses_stdin = false;
-    for (auto& filename : m_input_filenames) {
+    for (const auto& filename : m_input_filenames) {
         if (filename == "-") {
             if (uses_stdin) {
                 throw argument_error{"Can read at most one file from STDIN."};
